@@ -1,4 +1,4 @@
-#[cfg(feature = "std")]
+#[cfg(feature = "version-sync")]
 #[test]
 fn test_html_root_url() {
     version_sync::assert_html_root_url_updated!("src/lib.rs");
